@@ -3,7 +3,8 @@
 
    KsirK is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation, version 2.
+   License as published by the Free Software Foundation, either version 2
+   of the License, or (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -31,7 +32,6 @@
 #include <QPixmap>
 #include <QString>
 #include <QGridLayout>
-#include <kcmdlineargs.h>
 #include <QScrollBar>
 #include <QScrollArea>
 #include <QPalette>
@@ -71,19 +71,19 @@ KRightDialog::KRightDialog(QDockWidget * parent, ONU * world,KGameWindow* m_game
     delete sprite;
     
     // load the stopAttackAuto image
-    QString imageFileName = KGlobal::dirs()->findResource("appdata", skin + "/Images/stopAttackAuto.png");
+    QString imageFileName = QStandardPaths::locate(QStandardPaths::AppDataLocation, skin + "/Images/stopAttackAuto.png");
     stopAttackAuto.load(imageFileName);
 
     // load the recycle image
-    imageFileName = KGlobal::dirs()->findResource("appdata", skin + '/' +CM_RECYCLING);
+    imageFileName = QStandardPaths::locate(QStandardPaths::AppDataLocation, skin + '/' +CM_RECYCLING);
     recycleContinue.load(imageFileName);
 
     // load the finish recycle image
-    imageFileName = KGlobal::dirs()->findResource("appdata", skin + '/' + CM_RECYCLINGFINISHED);
+    imageFileName = QStandardPaths::locate(QStandardPaths::AppDataLocation, skin + '/' + CM_RECYCLINGFINISHED);
     recycleDone.load(imageFileName);
 
     // load the next player image
-    imageFileName = KGlobal::dirs()->findResource("appdata", skin + '/' + CM_NEXTPLAYER);
+    imageFileName = QStandardPaths::locate(QStandardPaths::AppDataLocation, skin + '/' + CM_NEXTPLAYER);
     recycleNextPlayer.load(imageFileName);
 
     show();
@@ -96,7 +96,7 @@ KRightDialog::~KRightDialog()
 
 void KRightDialog::displayCountryDetails(const QPointF& countryPoint)
 {
-  kDebug();
+  qCDebug(KSIRK_LOG);
   Country* country = world->countryAt(countryPoint);
   if (country == 0)
   {
@@ -127,8 +127,8 @@ void KRightDialog::displayCountryDetails(const QPointF& countryPoint)
   rightContents.at(4)->setText(i18n("<b>Owner:</b> %1", owner));
   rightContents.at(5)->setText(i18n("<b><u>Country details</u></b>"));
 
-  flag1->setPixmap(0);
-  flag2->setPixmap(0);
+  flag1->setPixmap(QPixmap());
+  flag2->setPixmap(QPixmap());
   flag1->setPixmap(picture);
 
   drap->addWidget(rightContents.at(0));
@@ -151,7 +151,7 @@ void KRightDialog::displayCountryDetails(const QPointF& countryPoint)
 
 void KRightDialog::displayFightDetails(Country * attaker, Country * defender,int nb_A, int nb_D)
 {
-  kDebug();
+  qCDebug(KSIRK_LOG);
 
   clearLayout();
   initListLabel(10);
@@ -180,7 +180,7 @@ void KRightDialog::displayFightDetails(Country * attaker, Country * defender,int
   KConfig config(world->getConfigFileName());
   KConfigGroup onugroup = config.group("onu");
   QString skin = onugroup.readEntry("skinpath");
-  QString imageFileName = KGlobal::dirs()->findResource("appdata", skin + "/Images/loader.gif");
+  QString imageFileName = QStandardPaths::locate(QStandardPaths::AppDataLocation, skin + "/Images/loader.gif");
 
   QMovie * loading = new QMovie(imageFileName);
   loadingLabel->setMovie(loading);
@@ -287,7 +287,7 @@ void KRightDialog::displayFightDetails(Country * attaker, Country * defender,int
 
  void KRightDialog::displayRecycleDetails(GameLogic::Player * player, int nbAvailArmies)
  {
-    kDebug() << player->name() << nbAvailArmies;
+    qCDebug(KSIRK_LOG) << player->name() << nbAvailArmies;
     this->show();
 
     clearLayout();
@@ -364,7 +364,7 @@ void KRightDialog::displayFightDetails(Country * attaker, Country * defender,int
 
 void KRightDialog::updateRecycleDetails(GameLogic::Country* country, bool recyclePhase, int nbAvailArmies)
 {
-  kDebug() << (void*)country << recyclePhase << nbAvailArmies;
+  qCDebug(KSIRK_LOG) << (void*)country << recyclePhase << nbAvailArmies;
   this->show();
   if (btValidWidget == 0)
   {
@@ -407,7 +407,7 @@ void KRightDialog::updateRecycleDetails(GameLogic::Country* country, bool recycl
       }
     }
   }
-  kDebug() << "before update and repaint";
+  qCDebug(KSIRK_LOG) << "before update and repaint";
   mainLayout->update();
   repaint();
 
@@ -415,7 +415,7 @@ void KRightDialog::updateRecycleDetails(GameLogic::Country* country, bool recycl
 
 void KRightDialog::displayFightResult(int A1=0, int A2=0, int A3=0, int D1=0, int D2=0,int nbA=0,int nbD=0, bool win=false)
 {
-  kDebug();
+  qCDebug(KSIRK_LOG);
 
   // Bug 309863. Should not happen anymore because Country details and Fight results shouldn't be mixed.
   // If, by any chance, occurs again, do not crash and log the incident. In that case label just won't be refreshed.
@@ -426,12 +426,12 @@ void KRightDialog::displayFightResult(int A1=0, int A2=0, int A3=0, int D1=0, in
     loadingLabel->clear();
   }
   else
-    kDebug() << "Item (loadingLabel) has already been cleared!";
+    qCDebug(KSIRK_LOG) << "Item (loadingLabel) has already been cleared!";
 
   if (infoProcess != 0)
     infoProcess->clear();
   else
-    kDebug() << "Item (infoProcess) has already been cleared!";
+    qCDebug(KSIRK_LOG) << "Item (infoProcess) has already been cleared!";
 
   milieu = new QWidget(this);
   milieu->setAutoFillBackground(true);
@@ -500,7 +500,7 @@ void KRightDialog::displayFightResult(int A1=0, int A2=0, int A3=0, int D1=0, in
 
 void KRightDialog::initListLabel(int nb)
 {
-  kDebug();
+  qCDebug(KSIRK_LOG);
 
   removeListLabel();
   for (int i=0;i<nb;i++)
@@ -514,7 +514,7 @@ void KRightDialog::initListLabel(int nb)
 
 void KRightDialog::removeListLabel()
 {
-  kDebug();
+  qCDebug(KSIRK_LOG);
   while (rightContents.size() > 0)
   {
     QLabel* label = rightContents.first();
@@ -525,17 +525,17 @@ void KRightDialog::removeListLabel()
 
 void KRightDialog::clearLabel()
 {
-  kDebug();
+  qCDebug(KSIRK_LOG);
   for (int i=0;i<rightContents.size();i++)
   {
     rightContents.at(i)->setText("");
-    rightContents.at(i)->setPixmap(0);
+    rightContents.at(i)->setPixmap(QPixmap());
   }
 }
 
 void KRightDialog::clearLayout()
 {
-  kDebug();
+  qCDebug(KSIRK_LOG);
   while (rightContents.size() > 0)
   {
     QLabel* obj = rightContents.first();
@@ -610,18 +610,18 @@ void KRightDialog::clearLayout()
 
 void KRightDialog::slotStopAttackAuto()
 {
-  kDebug();
+  qCDebug(KSIRK_LOG);
   this->game->automaton()->setAttackAuto(false);
   this->buttonStopAttack->setEnabled(false);
 }
 
 void KRightDialog::slotStopDefenseAuto()
 {
-  kDebug();
+  qCDebug(KSIRK_LOG);
   this->game->automaton()->setDefenseAuto(false);
   this->buttonStopDefense->setEnabled(false);
 }
 
 }
 
-#include "krightdialog.moc"
+
